==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("opyenajsmqufmbeh")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("mpvgqncnblilihmt")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mquyqxtoiaxjfymi")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xjyklveuwtujrjhh")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("lglvujhaftifobno")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("myjrtdgwwblgpems")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("jyefomangacaepyh")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs =
        DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("slvysaykxrxyapot")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("odgrnlpciguocgny")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("pcfcswkonuuhjsqm")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("uxiyjqxpcptwldta")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("llkjibhiruxxfjad")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("kvutkktncneleosf")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("hcrldovqwmalsgke")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs =
        DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}
